This package provides type hints for DataBricks utils python binding ([dbutils](https://docs.databricks.com/dev-tools/databricks-utils.html))

The package requires `python >= 3.5`

All contribution are welcome!